@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2017, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -37,6 +36,31 @@ from bokeh.util.serialization import make_id
 # Globals and constants
 #-----------------------------------------------------------------------------
 
+__all__ = (
+    'alt_click',
+    'ButtonWrapper',
+    'copy_table_rows',
+    'COUNT',
+    'element_to_finish_resizing',
+    'element_to_start_resizing',
+    'enter_text_in_cell',
+    'enter_text_in_cell_with_click_enter',
+    'enter_text_in_element',
+    'get_page_element',
+    'get_table_cell',
+    'get_table_column_cells',
+    'get_table_row',
+    'get_table_selected_rows',
+    'INIT',
+    'paste_values',
+    'RECORD',
+    'RESULTS',
+    'SCROLL',
+    'shift_click',
+    'sort_table_column',
+    'wait_for_canvas_resize',
+)
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
@@ -67,12 +91,12 @@ def alt_click(driver, element):
 
 class ButtonWrapper(object):
     def __init__(self, label, callback):
-        self.id = "button-" + make_id()
-        self.obj = Button(label=label, css_classes=[self.id])
+        self.ref = "button-" + make_id()
+        self.obj = Button(label=label, css_classes=[self.ref])
         self.obj.js_on_event('button_click', callback)
 
     def click(self, driver):
-        button = driver.find_element_by_class_name(self.id)
+        button = driver.find_element_by_css_selector(".%s .bk-btn" % self.ref)
         button.click()
 
 class element_to_start_resizing(object):
