@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -49,6 +48,7 @@ from .util.serialization import make_id
 __all__ = (
     'collect_models',
     'get_class',
+    'Model',
 )
 
 #-----------------------------------------------------------------------------
@@ -59,6 +59,49 @@ __all__ = (
 # Dev API
 #-----------------------------------------------------------------------------
 
+def collect_filtered_models(discard, *input_values):
+    ''' Collect a duplicate-free list of all other Bokeh models referred to by
+    this model, or by any of its references, etc, unless filtered-out by the
+    provided callable.
+
+    Iterate over ``input_values`` and descend through their structure
+    collecting all nested ``Models`` on the go.
+
+    Args:
+        *discard (Callable[[Model], bool])
+            a callable which accepts a *Model* instance as its single argument
+            and returns a boolean stating whether to discard the instance. The
+            latter means that the instance will not be added to collected
+            models nor will its references be explored.
+
+        *input_values (Model)
+            Bokeh models to collect other models from
+
+    Returns:
+        None
+
+    '''
+
+    ids = set([])
+    collected = []
+    queued = []
+
+    def queue_one(obj):
+        if obj.id not in ids and not (callable(discard) and discard(obj)):
+            queued.append(obj)
+
+    for value in input_values:
+        _visit_value_and_its_immediate_references(value, queue_one)
+
+    while queued:
+        obj = queued.pop(0)
+        if obj.id not in ids:
+            ids.add(obj.id)
+            collected.append(obj)
+            _visit_immediate_value_references(obj, queue_one)
+
+    return collected
+
 def collect_models(*input_values):
     ''' Collect a duplicate-free list of all other Bokeh models referred to by
     this model, or by any of its references, etc.
@@ -75,26 +118,7 @@ def collect_models(*input_values):
         list[Model] : all models reachable from this one.
 
     '''
-
-    ids = set([])
-    collected = []
-    queued = []
-
-    def queue_one(obj):
-        if obj.id not in ids:
-            queued.append(obj)
-
-    for value in input_values:
-        _visit_value_and_its_immediate_references(value, queue_one)
-
-    while queued:
-        obj = queued.pop(0)
-        if obj.id not in ids:
-            ids.add(obj.id)
-            collected.append(obj)
-            _visit_immediate_value_references(obj, queue_one)
-
-    return collected
+    return collect_filtered_models(None, *input_values)
 
 def get_class(view_model_name):
     ''' Look up a Bokeh model class, given its view model name.
@@ -254,10 +278,32 @@ class Model(with_metaclass(MetaModel, HasProps, PropertyCallbackManager, EventCa
 
     '''
 
+    def __new__(cls, *args, **kwargs):
+        obj =  super(Model, cls).__new__(cls)
+        obj._id = kwargs.pop("id", make_id())
+        obj._document = None
+        obj._temp_document = None
+        return obj
+
     def __init__(self, **kwargs):
-        self._id = kwargs.pop("id", make_id())
-        self._document = None
-        self._temp_document = None
+
+        # "id" is popped from **kw in __new__, so in an ideal world I don't
+        # think it should be here too. But Python does this, so it is:
+        #
+        # class Foo(object):
+        #     def __new__(cls, *args, **kw):
+        #         obj = super(Foo, cls).__new__(cls)
+        #         obj.bar = kw.pop("bar", 111)
+        #         print("__new__  :", id(kw), kw)
+        #         return obj
+        #     def __init__(self, **kw):
+        #         print("__init__ :", id(kw), kw)
+        #
+        # >>> f = Foo(bar=10)
+        # __new__  : 4405522296 {}
+        # __init__ : 4405522296 {'bar': 10}
+        kwargs.pop("id", None)
+
         super(Model, self).__init__(**kwargs)
         default_theme.apply_to_model(self)
 
@@ -400,6 +446,63 @@ class Model(with_metaclass(MetaModel, HasProps, PropertyCallbackManager, EventCa
             self.js_event_callbacks[event].append(callback)
 
 
+    def js_link(self, attr, other, other_attr):
+        ''' Link two Bokeh model properties using JavaScript.
+
+        This is a convenience method that simplifies adding a CustomJS callback
+        to update one Bokeh model property whenever another changes value.
+
+        Args:
+
+            attr (str) :
+                The name of a Bokeh property on this model
+
+            other (Model):
+                A Bokeh model to link to self.attr
+
+            other_attr (str) :
+                The property on ``other`` to link together
+
+        Added in version 1.1
+
+        Raises:
+
+            ValueError
+
+        Examples:
+
+            This code with ``js_link``:
+
+            .. code :: python
+
+                select.js_link('value', plot, 'sizing_mode')
+
+            is equivalent to the following:
+
+            .. code:: python
+
+                from bokeh.models import CustomJS
+                select.js_on_change('value',
+                    CustomJS(args=dict(other=plot),
+                             code="other.sizing_mode = this.value"
+                    )
+                )
+
+        '''
+        if attr not in self.properties():
+            raise ValueError("%r is not a property of self (%r)" % (attr, self))
+
+        if not isinstance(other, Model):
+            raise ValueError("'other' is not a Bokeh model: %r" % other)
+
+        if other_attr not in other.properties():
+            raise ValueError("%r is not a property of other (%r)" % (other_attr, other))
+
+        from bokeh.models.callbacks import CustomJS
+        cb = CustomJS(args=dict(other=other), code="other.%s = this.%s" % (other_attr, attr))
+
+        self.js_on_change(attr, cb)
+
     def js_on_change(self, event, *callbacks):
         ''' Attach a ``CustomJS`` callback to an arbitrary BokehJS model event.
 
