@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -33,9 +32,10 @@ from ..core.properties import Bool, Dict, Enum, Include, Instance, Int, List, Ov
 from ..core.property_mixins import LineProps, FillProps
 from ..core.query import find
 from ..core.validation import error, warning
-from ..core.validation.errors import  BAD_EXTRA_RANGE_NAME, REQUIRED_RANGE, REQUIRED_SCALE, INCOMPATIBLE_SCALE_AND_RANGE
-from ..core.validation.warnings import MISSING_RENDERERS
-from ..model import Model
+from ..core.validation.errors import BAD_EXTRA_RANGE_NAME, REQUIRED_RANGE, REQUIRED_SCALE, INCOMPATIBLE_SCALE_AND_RANGE
+from ..core.validation.warnings import MISSING_RENDERERS, FIXED_SIZING_MODE, FIXED_WIDTH_POLICY, FIXED_HEIGHT_POLICY
+from ..model import Model, collect_filtered_models
+from ..util.deprecation import deprecated
 from ..util.string import nice_join
 
 from .annotations import Legend, Title
@@ -182,7 +182,8 @@ class Plot(LayoutDOM):
         ''' Splattable list of :class:`~bokeh.models.annotations.Legend` objects.
 
         '''
-        legends = [obj for obj in self.renderers if isinstance(obj, Legend)]
+        panels = self.above + self.below + self.left + self.right + self.center
+        legends = [obj for obj in panels if isinstance(obj, Legend)]
         return _legend_attr_splat(legends)
 
     @property
@@ -194,7 +195,7 @@ class Plot(LayoutDOM):
         return _list_attr_splat(hovers)
 
     def _grid(self, dimension):
-        grid = [obj for obj in self.renderers if isinstance(obj, Grid) and obj.dimension==dimension]
+        grid = [obj for obj in self.center if isinstance(obj, Grid) and obj.dimension == dimension]
         return _list_attr_splat(grid)
 
     @property
@@ -244,15 +245,7 @@ class Plot(LayoutDOM):
                 "Invalid place '%s' specified. Valid place values are: %s" % (place, nice_join(valid_places))
             )
 
-        if hasattr(obj, 'plot'):
-            if obj.plot is not None:
-                raise ValueError("object to be added already has 'plot' attribute set")
-            obj.plot = self
-
-        self.renderers.append(obj)
-
-        if place != 'center':
-            getattr(self, place).append(obj)
+        getattr(self, place).append(obj)
 
     def add_tools(self, *tools):
         ''' Adds tools to the plot.
@@ -268,9 +261,6 @@ class Plot(LayoutDOM):
             if not isinstance(tool, Tool):
                 raise ValueError("All arguments to add_tool must be Tool subclasses.")
 
-            if hasattr(tool, 'overlay'):
-                self.renderers.append(tool.overlay)
-
             self.toolbar.tools.append(tool)
 
     def add_glyph(self, source_or_glyph, glyph=None, **kw):
@@ -378,8 +368,9 @@ class Plot(LayoutDOM):
 
     @error(BAD_EXTRA_RANGE_NAME)
     def _check_bad_extra_range_name(self):
-        msg = ""
-        for ref in self.references():
+        msg  = ""
+        filt = lambda x: x is not self and isinstance(x, Plot)
+        for ref in collect_filtered_models(filt, self):
             prop_names = ref.properties()
             bad = []
             if 'x_range_name' in prop_names and 'y_range_name' in prop_names:
@@ -493,26 +484,37 @@ class Plot(LayoutDOM):
     A list of renderers to occupy the area below of the plot.
     """)
 
-    plot_height = Int(600, help="""
-    Total height of the entire plot (including any axes, titles,
-    border padding, etc.)
-
-    .. note::
-        This corresponds directly to the height of the HTML
-        canvas that will be used.
-
+    center = List(Instance(Renderer), help="""
+    A list of renderers to occupy the center area (frame) of the plot.
     """)
 
     plot_width = Int(600, help="""
-    Total width of the entire plot (including any axes, titles,
-    border padding, etc.)
+    The outer width of a plot, including any axes, titles, border padding, etc.
 
     .. note::
-        This corresponds directly to the width of the HTML
-        canvas that will be used.
+        This corresponds directly to the width of the HTML canvas.
 
     """)
 
+    plot_height = Int(600, help="""
+    The outer height of a plot, including any axes, titles, border padding, etc.
+
+    .. note::
+        This corresponds directly to the height of the HTML canvas.
+
+    """)
+
+    frame_width = Int(default=None, help="""
+    The width of a plot frame or the inner width of a plot, excluding any
+    axes, titles, border padding, etc.
+    """)
+
+    frame_height = Int(default=None, help="""
+    The height of a plot frame or the inner height of a plot, excluding any
+    axes, titles, border padding, etc.
+    """)
+
+
     inner_width = Int(readonly=True, help="""
     This is the exact width of the plotting canvas, i.e. the width of
     the actual plot, without toolbars etc. Note this is computed in a
@@ -535,7 +537,7 @@ class Plot(LayoutDOM):
 
     """)
 
-    layout_width = Int(readonly=True, help="""
+    outer_width = Int(readonly=True, help="""
     This is the exact width of the layout, i.e. the height of
     the actual plot, with toolbars etc. Note this is computed in a
     web browser, so this property will work only in backends capable of
@@ -546,7 +548,7 @@ class Plot(LayoutDOM):
 
     """)
 
-    layout_height = Int(readonly=True, help="""
+    outer_height = Int(readonly=True, help="""
     This is the exact height of the layout, i.e. the height of
     the actual plot, with toolbars etc. Note this is computed in a
     web browser, so this property will work only in backends capable of
@@ -615,15 +617,22 @@ class Plot(LayoutDOM):
     it will override ``min_border``.
     """)
 
-    h_symmetry = Bool(True, help="""
-    Whether the total horizontal padding on both sides of the plot will
-    be made equal (the left or right padding amount, whichever is larger).
-    """)
 
-    v_symmetry = Bool(False, help="""
-    Whether the total vertical padding on both sides of the plot will
-    be made equal (the top or bottom padding amount, whichever is larger).
-    """)
+    @property
+    def h_symmetry(self):
+        deprecated("h_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
+
+    @h_symmetry.setter
+    def h_symmetry(self, _):
+        deprecated("h_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
+
+    @property
+    def v_symmetry(self):
+        deprecated("v_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
+
+    @v_symmetry.setter
+    def v_symmetry(self, _):
+        deprecated("v_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
 
     lod_factor = Int(10, help="""
     Decimation factor to use when applying level-of-detail decimation.
@@ -691,6 +700,19 @@ class Plot(LayoutDOM):
         This setting only takes effect if ``match_aspect`` is set to ``True``.
     """)
 
+    # XXX: override LayoutDOM's definitions because of plot_{width,height}.
+    @error(FIXED_SIZING_MODE)
+    def _check_fixed_sizing_mode(self):
+        pass
+
+    @error(FIXED_WIDTH_POLICY)
+    def _check_fixed_width_policy(self):
+        pass
+
+    @error(FIXED_HEIGHT_POLICY)
+    def _check_fixed_height_policy(self):
+        pass
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
@@ -715,7 +737,7 @@ class _list_attr_splat(list):
             return dir(self)
 
 _LEGEND_EMPTY_WARNING = """
-You are attemptings to set `plot.legend.%s` on a plot that has zero legends added, this will have no effect.
+You are attempting to set `plot.legend.%s` on a plot that has zero legends added, this will have no effect.
 
 Before legend properties can be set, you must add a Legend explicitly, or call a glyph method with the 'legend' parameter set.
 """
