@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -632,6 +631,8 @@ class DataTable(TableWidget):
     Whether to show a header row with column names at the top of the table.
     """)
 
+    width = Override(default=600)
+
     height = Override(default=400)
 
     row_height = Int(25, help="""
