@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -19,7 +18,11 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from collections import Iterable, OrderedDict, Sequence
+from collections import OrderedDict
+from bokeh.util.future import collections_abc # goes away with py2
+Iterable = collections_abc.Iterable # NOQA
+Sequence = collections_abc.Sequence # NOQA
+
 import difflib
 import itertools
 import re
@@ -527,10 +530,9 @@ def _tool_from_string(name):
 
 def _process_axis_and_grid(plot, axis_type, axis_location, minor_ticks, axis_label, rng, dim):
     axiscls, axiskw = _get_axis_class(axis_type, rng, dim)
-    if axiscls:
 
-        # this is so we can get a ticker off the axis, even if we discard it
-        axis = axiscls(plot=plot if axis_location else None, **axiskw)
+    if axiscls:
+        axis = axiscls(**axiskw)
 
         if isinstance(axis.ticker, ContinuousTicker):
             axis.ticker.num_minor_ticks = _get_num_minor_ticks(axiscls, minor_ticks)
@@ -539,7 +541,8 @@ def _process_axis_and_grid(plot, axis_type, axis_location, minor_ticks, axis_lab
         if axis_label:
             axis.axis_label = axis_label
 
-        grid = Grid(plot=plot, dimension=dim, ticker=axis.ticker); grid
+        grid = Grid(dimension=dim, ticker=axis.ticker)
+        plot.add_layout(grid, "center")
 
         if axis_location is not None:
             getattr(plot, axis_location).append(axis)
